componenttools.partition_components_cyclically_by_prolated_durations_ge_without_overhang
========================================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_cyclically_by_prolated_durations_ge_without_overhang.partition_components_cyclically_by_prolated_durations_ge_without_overhang
